OC.L10N.register(
    "oauth2",
    {
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "כתובת ההפניה שלך חייבת להיות כתובת מלאה, למשל: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "OAuth 2.0 clients" : "לקוחות OAuth 2.0",
    "Name" : "שם",
    "Redirection URI" : "כתובת הפנייה",
    "Client Identifier" : "זיהוי לקו",
    "Secret" : "סוד",
    "Add client" : "הוספת לקוחי",
    "Add" : "הוספה",
    "Show client secret" : "הצגת סוד לקוח",
    "Delete" : "מחיקה"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
